<!--  -->
<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" label-width="70px">
      <el-row align="left">
        <el-col :span="6">
          <el-form-item label="姓名" prop="name">
            <el-input v-model="queryParams.name" placeholder="请输入姓名" clearable size="small"
              @keyup.enter.native="handleQuery" />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="捐献进度" prop="recordstate">
            <el-select v-model="queryParams.recordstate" placeholder="请选择记录状态" clearable size="small">
              <el-option v-for="dict in dict.type.sys_DonationStatus" :key="dict.value" :label="dict.label"
                :value="dict.value" />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
          <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
        </el-col>
      </el-row>
    </el-form>
    <el-row>
      <el-col :span="6">
        <el-card shadow="never">
          <!-- 捐献案例列表 -->
          <el-row>
            <el-col :span="10">
              <el-row type="flex" :gutter="10" align="right" class="mb8">
              </el-row>
            </el-col>
          </el-row>
          <el-table v-loading="loading" border highlight-current-row :data="donatebaseinfoList"
            @row-click="selectDonotor">
            <!-- <el-table-column label="捐献编号" align="center" prop="donorno" /> -->
            <el-table-column label="捐献进度" align="center" prop="recordstate">
              <template slot-scope="scope">
                <dict-tag :options="dict.type.sys_DonationStatus" :value="scope.row.recordstate" />
              </template>
            </el-table-column>
            <el-table-column label="姓名" align="center" prop="name" />
          </el-table>
          <pagination v-show="total > 0" :total="total" small :page.sync="queryParams.pageNum"
            :limit.sync="queryParams.pageSize" @pagination="getBaseInfoList" />
        </el-card>
      </el-col>
      <el-col :span="18">
        <el-card shadow="naver">
          <el-form ref="infoform" label-width="100px">
            <el-row :gutter="4" align="right" class="mb8">
              <el-col :span="9">
                <el-form-item label="捐献编号">
                  <el-input v-model="curCase.donorno" :disabled="true"></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="9">
                <el-form-item label="姓名">
                  <el-input v-model="curCase.name" :disabled="true"></el-input>
                </el-form-item>
              </el-col>
              <el-col> </el-col>
            </el-row>
            <el-row :gutter="10" class="mb8">
              <el-col :span="1.5">
                <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
                  v-hasPermi="['project:medicalfund:add']">新增申请单</el-button>
              </el-col>
            </el-row>
            <el-row>
              <el-table v-loading="loading" border :data="donateconsolationfundList">
                <el-table-column label="申请日期" align="center" prop="createTime" width="150px">
                  <template slot-scope="scope">
                    <span>{{
                      parseTime(scope.row.createTime, "{y}-{m}-{d}")
                    }}</span>
                  </template>
                </el-table-column>
                <el-table-column label="申请人" align="center" prop="username" width="120px" />
                <el-table-column label="申请金额" align="center" prop="pretaxcost" width="200px" />
                <el-table-column label="所属组别" align="center" prop="deptmentname" width="220px" />
                <el-table-column label="组长" align="center" prop="managername" width="200px" />
                <el-table-column label="审核状态" align="center" prop="recordstatus">
                  <template slot-scope="scope">
                    <dict-tag :options="dict.type.sys_recordstatus" :value="scope.row.recordstatus" />
                  </template>
                </el-table-column>
                <!--
                  <el-table-column label="联系电话" align="center" prop="phone" width="150px" />
                <el-table-column label="工作单位" align="center" prop="unitname" width="150px" />
                -->
                <el-table-column label="操作" fixed="right" align="center" class-name="small-padding fixed-width"
                  width="280px">
                  <template slot-scope="scope">
                    <el-button v-if="scope.row.recordstatus == -1 ||
                      scope.row.recordstatus == 1
                      " size="mini" type="text" icon="el-icon-edit" @click="handleup(scope.row)">上报</el-button>
                    <el-button v-if="scope.row.recordstatus == -1 ||
                      scope.row.recordstatus == 1
                      " size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
                      v-hasPermi="['project:medicalfund:edit']">修改</el-button>
                    <el-button size="mini" type="text" icon="el-icon-view" @click="handleDetail(scope.row)">查看</el-button>
                    <el-button v-if="scope.row.recordstatus == -1 ||
                      scope.row.recordstatus == 1
                      " size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
                      v-hasPermi="['project:medicalfund:delete']">删除</el-button>
                    <el-button size="mini" type="text" icon="el-icon-download" @click="mixExport(scope.row.id)"
                      v-hasPermi="['project:medicalfund:download']">下载</el-button>
                  </template>
                </el-table-column>
              </el-table>
            </el-row>
          </el-form>
        </el-card>
      </el-col>
    </el-row>

  </div>
</template>

<script>
//这里可以导入其他文件（比如：组件，工具js，第三方插件js，json文件，图片文件等等）
//例如：import 《组件名称》 from '《组件路径》';
import {
  onelistFund,
  listFund,
  getFund,
  delFund,
  addFund,
  updateFund,
  exportFund,
  getdownloadLW,
  getdownloadSH,
  getdownloadSS,
  getdownloadYX,
  getdownloadBX,
  addorupdateFund,
  getdetailsByItemId
} from "@/api/project/fund";
import {
  onelistFunds,
  listFunddetails,
  listFunddetail,
  getFunddetail,
  delFunddetail,
  addFunddetail,
  getownFundDetail,
  updateFunddetail,
  exportFunddetail,
  getItemNames,
  getFundType,
  getFundTypeAll,
  listcountItem
} from "@/api/project/funddetail";
import {
  listOrganization,
  getOrganization,
  listReportname,
  listUser
} from "@/api/project/organization";
import {
  listExternalperson,
  getExternalperson,
  getInfoBytheUserNo,
  delExternalperson,
  addExternalperson,
  updateExternalperson,
  exportExternalperson
} from "@/api/project/externalperson";
import {
  listDonatebaseinfo,
  getDonatebaseinfo
} from "@/api/project/donatebaseinfo";
import Li_area_select from "@/components/Address";
import OrgSelecter from "@/views/project/components/orgselect";
import { getUserProfile } from "@/api/system/user";
import { listFundflow } from "@/api/project/fundflow";
import { getToken } from "@/utils/auth";

export default {
  //import引入的组件需要注入到对象中才能使用
  components: {
    Li_area_select,
    OrgSelecter
  },
  name: "fundApply",
  dicts: [
    "sys_recordstatus",
    "sys_OrganizationType",
    "sys_DonationStatus",
    "sys_depositbank",
    "sys_FamilyRelation",
    "sys_IDType",
    "sys_ConsolationType",
    "sys_fund_type",
    "sys_finsubject",
    "sys_financeitemtype",
    "sys_expensetype"
  ],
  data() {
    //这里存放数据
    return {
      currentApplyType: "3",
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      total: 0,
      queryParams: {
        organizationname: null,
        organizationtype: null,
        pageNum: 1,
        pageSize: 10,
        name: null,
        idcardno: null,
        residenceprovince: null,
        residencecity: null,
        residencetown: null,
        recordstate: null,
        treatmenthospitalname: null,
        donorno: null,
        reportername: null,
        reporttime: null
      },

      fundQueryParam: {
        pageNum: 1,
        pageSize: 100,
        infoid: null,
        applytype: "3",
        createBy: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        username: [
          { required: true, message: "请输入申请人", trigger: "blur" }
        ],
        createTime: [
          { required: true, message: "请输入申请日期", trigger: "blur" }
        ],
        deptmentname: [
          { required: true, message: "请输入所属业务组", trigger: "blur" }
        ]
      },

      //捐献案例列表数据
      // donationCaseTableData:[],
      donatebaseinfoList: [],
      //当前选中捐献案例
      curCase: {},
      //是否显示费用申请弹窗
      dialogOpen: false,
      // title: "",
      //费用申请表单title
      applyFormTitle: "",

      // 捐献人道慰问金表格数据
      donateconsolationfundList: [],

      //明细记录
      fundDetails: [],

      // 弹出层标题
      title: "",
      itemArr: [],
      //用户
      userlist: [],
      //银行账号
      bankaccountlist: [],
      //机构单位
      unitList: [],
      //费用类型数组
      fundtypeArr: [],
      defaultperson: {},
      fundblock: [],
      fundtypeArrAll: [],
      dialogType: "edit",

      detailInfoDialogShow: false,
      detailInfoDialogShowType: "",
      funddetailForm: {
        beneficiaryname: null,
        beneficiaryno: null,
        unitno: null,
        unitname: null,
        index: null
      },

      //附件列表
      fileList: [],
      fileListto: [],
      //上传附件路径
      uploadFileUrl: process.env.VUE_APP_BASE_API + "/common/upload",
      headers: {
        Authorization: "Bearer " + getToken()
      },
      //票据文件
      pdftitle: "",
      pdfimg: "",
      pdfVisible: false,
      previewpdf: false,
      hintitle: "选中左侧已上传文件预览查看",
      atpresent: ""
    };
  },
  //监听属性 类似于data概念
  computed: {},
  //监控data中的数据变化
  watch: {},
  //生命周期 - 创建完成（可以访问当前this实例）
  created() {
    this.getList();
    this.getBaseInfoList();
    this.getCurFundType();
    this.getlistUser();
    // this.getUnitList();
  },

  //生命周期 - 挂载完成（可以访问DOM元素）
  mounted() {
    this.getBankAccount();
    this.getUsermsg();
  },

  beforeCreate() { }, //生命周期 - 创建之前
  beforeMount() { }, //生命周期 - 挂载之前
  beforeUpdate() { }, //生命周期 - 更新之前
  updated() { }, //生命周期 - 更新之后
  beforeDestroy() { }, //生命周期 - 销毁之前
  destroyed() { }, //生命周期 - 销毁完成
  activated() { }, //如果页面有keep-alive缓存功能，这个函数会触发

  //方法集合
  methods: {
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.daterangeReporttime = [];

      this.resetForm("queryForm");
      this.handleQuery();
    },

    /** 查询捐献人道慰问金列表 */
    getList() {
      this.loading = true;
      this.queryParams.params = {};
      if (null != this.daterangeReporttime && "" != this.daterangeReporttime) {
        this.queryParams.params[
          "beginReporttime"
        ] = this.daterangeReporttime[0];
        this.queryParams.params["endReporttime"] = this.daterangeReporttime[1];
      }
      // this.queryParams.residencetown = this.$refs.areaSelect.getQu();
      listDonatebaseinfo(this.queryParams).then(response => {
        this.donatebaseinfoList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },

    /** 新增按钮操作 */
    handleAdd() {
      if (this.curCase.id) {
        this.$router.push({
          path: "/finance/applyDetail/",
          query: {
            id: 0,
            businessType: "3",
            operationType: "add",
            curCase: this.curCase
          }
        });
      } else {
        const h = this.$createElement;
        this.$message({
          message: h("p", null, [h("span", null, "请在左边的捐献案例表选择需要操作的案例！")]),
        });
      }
      return;

      if (this.curCase.id) {
        this.istrue += 2;
        this.reset();
        this.queryParams.params = {};
        this.form.donorno = this.curCase.donorno;
        this.form.name = this.curCase.name;
        this.form.infoid = this.curCase.id;
        this.form.username = this.defaultperson.nickName;
        this.form.userno = this.defaultperson.userName;
        this.form.deptmentname = this.defaultperson.dept.deptName;
        this.form.deptmentno = this.defaultperson.dept.deptId;
        this.form.managername = this.defaultperson.dept.leader;

        // this.form.createTime = nowdate;
        //this.open = true;
        //this.initFundApplyForm();
        this.fundDetails = [];
        this.addRow();
        this.dialogOpen = true;
        this.title = "添加费用申请";
        this.dialogType = "edit";
      } else {
        const h = this.$createElement;
        this.$message({
          message: h("p", null, [h("span", null, "请先选择左方捐献案例 ")])
        });
      }
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.$router.push({
        path: "/finance/applyDetail/",
        query: {
          id: row.id,
          businessType: "3",
          operationType: "update",
          curCase: this.curCase
        }
      });
      return;

      this.isopen = 0;
      this.reset();
      this.queryParams.params = {};
      this.form.donorno = this.curCase.donorno;
      this.form.infoid = this.curCase.id;
      this.dialogType = "edit";
      this.dialogOpen = true;
      this.title = "修改费用申请";

      const id = row.id || this.ids;
      getFund(id).then(response => {
        this.form = response.data;
        this.form.name = this.curCase.name;
        //附件处理
        this.fileList = this.form.annexbankcard
          ? this.form.annexbankcard
            .split(",")
            .map(item => ({ url: item, name: item }))
          : [];

        getownFundDetail(id).then(async res => {
          this.fundDetails = res.data;
          for (let m = 0; m < this.fundDetails.length; m++) {
            this.fundDetails[m].itemArr = [];
            this.getItemArr(m, this.fundDetails[m]);
          }
        });
      });
    },

    /** 查看按钮操作 */
    handleDetail(row) {
      this.$router.push({
        path: "/finance/applyDetail/",
        query: {
          id: row.id,
          businessType: "3",
          operationType: "detail",
          curCase: this.curCase
        }
      });
      return;

      this.isopen = 0;
      this.reset();
      this.queryParams.params = {};
      this.form.donorno = this.curCase.donorno;
      this.form.infoid = this.curCase.id;
      this.dialogOpen = true;
      this.title = "查看费用申请";
      this.dialogType = "detail";
      const id = row.id || this.ids;

      getFund(id).then(response => {
        this.form = response.data;
        this.form.name = this.curCase.name;
        let listFundflowparams = {
          fundid: row.id,
          fundtype: 2
        };
        //附件处理
        this.fileList = this.form.annexbankcard
          ? this.form.annexbankcard
            .split(",")
            .map(item => ({ url: item, name: item }))
          : [];

        listFundflow(listFundflowparams).then(res => {
          this.fundflowList = res.rows;
        });
        getownFundDetail(id).then(res => {
          this.fundDetails = res.data;
          for (let m = 0; m < this.fundDetails.length; m++) {
            this.fundDetails[m].itemArr = [];
            this.getItemArr(m, this.fundDetails[m]);
            this.fundDetails[m].fundblock = [];
            this.fundDetails[m].fundblock.push({
              expense: this.fundDetails[m].expense,
              expensedescribe: this.fundDetails[m].servicesscopename,
              remark: this.fundDetails[m].servicesscope,
              servicesscope: this.fundDetails[m].servicesscope
            });
          }
        });
      });
    },

    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal
        .confirm("是否确认删除该记录？")
        .then(function () {
          return delFund(ids);
        })
        .then(() => {
          getownFundDetail(ids).then(res => {
            let listdetails = res.data;
            for (let i = 0; i < listdetails.length; i++) {
              delFunddetail(listdetails[i].id);
            }
          });
          // this.getList();
          this.getfundList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => { });
    },

    /** 上报按钮操作 */
    handleup(row) {
      this.$confirm("是否确认将登记记录上报？", "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          //查找是否存在登记完成记录
          //判断是否存在上报记录
          row.recordstatus = 0;

          updateFund(row).then(response => {
            if (response.code == 200) {
              this.$message({
                type: "success",
                message: "申请成功"
              });
            } else {
              this.$message({
                type: "error",
                message: "申请失败"
              });
            }
            this.loading = false;
          });
        })
        .catch(() => {
          this.$message({
            type: "info",
            message: "已取消申请"
          });
        });
    },

    ShowDetailDialog(spoce, showType) {
      this.funddetailForm.index = spoce.$index;
      this.funddetailForm.beneficiaryno = spoce.row.beneficiaryno;
      this.funddetailForm.beneficiaryname = spoce.row.beneficiaryname;
      this.funddetailForm.unitno = spoce.row.unitno;
      this.funddetailForm.unitname = spoce.row.unitname;
      this.detailInfoDialogShow = true;
      this.detailInfoDialogShowType = showType;
    },

    ConfirmDetailDialog() {
      let tempIndex = this.funddetailForm.index;
      let tempName = this.funddetailForm.beneficiaryname;
      let tempUnitname = this.funddetailForm.unitname;
      let singleDetail = this.fundDetails[tempIndex];
      if (this.detailInfoDialogShowType == "name") {
        this.personlist.map(res => {
          if (tempName == res.username) {
            singleDetail.beneficiaryno = res.userno;
            singleDetail.beneficiaryname = res.username;
            singleDetail.bankcardno = res.bankcardno;
            singleDetail.branchbankname = res.branchbankname;
            singleDetail.depositbank = res.depositbank;
            singleDetail.idcardno = res.idcardno;
            singleDetail.phone = res.telephone;
            singleDetail.title = res.title;
            singleDetail.unitname = res.unitname;
            singleDetail.unitno = res.unitno;
          } else {
            singleDetail.beneficiaryname = tempName;
            singleDetail.beneficiaryno = tempName;
          }
        });
      } else if (this.detailInfoDialogShowType == "unit") {
        singleDetail.unitno = this.funddetailForm.unitno;
        try {
          let unitIndex = this.bankaccountlist.findIndex(
            item => singleDetail.unitno == item.reportNo
          );

          if (unitIndex > -1) {
            singleDetail.unitname = this.bankaccountlist[unitIndex].reportName;
            singleDetail.depositbank = this.bankaccountlist[
              unitIndex
            ].depositbank;
            singleDetail.bankcardno = this.bankaccountlist[
              unitIndex
            ].bankcardno;
          } else {
            singleDetail.unitname = singleDetail.unitno;
          }
        } catch {
          singleDetail.unitname = singleDetail.unitno;
        }
      }

      this.fundDetails[tempIndex] = singleDetail;
      this.detailInfoDialogShow = false;
    },

    selectremark(row) {
      this.fundblock.forEach((item, i) => {
        if (item.expensedescribe === row.servicesscopename) {
          row.servivesscope = item.servivesscope;
          row.amount = item.expense;
          this.form.serviceFunddetails = 0;
          this.fundDetails.map(item => {
            this.form.serviceFunddetails += item.amount;
          });
        }
      });
    },

    select(row) {
      row.itemArr.map(res => {
        if (row.itemid === res.id) {
          row.remark = res.itemDescribe;
          row.itemcode = res.itemCode;
        }
      });
      var repeatNum = 0;
      this.fundDetails.map(res => {
        if (res.applytype === row.applytype && res.itemid == row.itemid) {
          repeatNum++;
        }
      });
      if (repeatNum > 1) {
        this.$modal.msgWarning("您已经提交过服务项目");
      }

      getdetailsByItemId(row.itemid).then(res => {
        let fundmsg = res.data;
        let fundblock = [];
        fundmsg.forEach(item => {
          fundblock.push({
            expense: item.expense,
            expensedescribe: item.expensedescribe,
            remark: item.expensedescribe,
            servicesscope: item.id
          });
        });
        row.fundblock = fundblock;
        row.servicesscope = null;
        row.servicesscopename = "";
      });
    },
    selectamount(row) {
      this.fundblock.forEach((item, i) => {
        if (item.expense === row.amount) {
          row.remark = item.expensedescribe;
        }
      });
    },
    getUsermsg() {
      getUserProfile().then(response => {
        this.defaultperson = response.data;
        this.standardlevel = response.data.standardlevel;
      });
    },

    getBaseInfoList() {
      this.loading = true;
      listDonatebaseinfo(this.queryParams).then(response => {
        this.donatebaseinfoList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },

    //点击捐献案例列表触发方法
    selectDonotor(row, column, event) {
      this.curCase = row;
      this.getfundList();
    },

    getfundList() {
      this.loading = true;
      this.reset();
      this.fundQueryParam.infoid = this.curCase.id;
      listFund(this.fundQueryParam).then(response => {
        this.loading = false;
        this.donateconsolationfundList = response.rows;
      });
    },

    // 取消按钮
    cancel() {
      this.dialogOpen = false;
      this.reset();
    },

    // 表单重置
    reset() {
      this.form = {
        recordstate: -1,
        username: null,
        userno: null,
        id: null,
        infoid: null,
        donorno: null,
        delFlag: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        familyrelations: null,
        name: null,
        doname: null,
        unitname: null,
        unitno: null,
        sex: null,
        idcardtype: null,
        idcardno: null,
        phone: null,
        donorname: null,
        depositbank: null,
        bankprovince: null,
        bankprovincename: null,
        bankcity: null,
        bankcityname: null,
        banktown: null,
        banktownname: null,
        branchbankname: null,
        bankcardno: null,
        annexbankcard: null,
        annexregistform: null,
        consolationmoney: null,
        applytype: "3",
        recordstatus: -1,
        servicetypename: null,
        servicesscopename: null,
        dialogType: "edit",
        fundflowList: []
      };
      this.resetForm("form");

      //清空附件
      this.fileList = [];
    },

    //新增一行
    addRow(rowIndex) {
      let rowData = {
        orderno: null,
        id: null,
        fundid: null,
        beneficiaryname: "点击选择",
        beneficiaryno: null,
        unitname: "点击选择",
        unitno: null,
        uintuserno: null,
        title: null,
        idcardtype: null,
        idcardno: null,
        sex: null,
        familyrelations: null,
        phone: null,
        depositbank: null,
        bankcardno: null,
        branchbankname: null,
        annexbankcard: null,
        annexregistform: null,
        applytype: null,
        itemid: null,
        itemname: null,
        itemtype: null,
        amount: null,
        prepaidamount: null,
        taxamount: null,
        invoicecount: null,
        taxedamount: null,
        attachcount: null,
        remark: null,
        recordstatus: "0",
        delFlag: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        uploadflag: null,
        uploadtime: null,
        itemArr: [],
        servivesscope: null
      };
      if (rowIndex == undefined || rowIndex == null || rowIndex < 0) {
        this.fundDetails.push(rowData);
      } else {
        this.fundDetails.splice(rowIndex + 1, 0, rowData);
      }
      for (let i = 0; i < this.fundDetails.length; i++) {
        this.fundDetails[i].orderno = i + 1;
      }
    },

    //加载服务项目
    LoadItemTypeArr(row) {
      let list = this.fundtypeArrAll.filter(r => r.itemType == row.applytype);
      row.itemArr = list[0].itemDetails;
      row.itemid = null;
      this.$forceUpdate();
      //this.loading = true;
      // getItemNames(row.applytype).then((res) => {
      //   this.loading = false;
      //   row.itemid = null;
      //   row.itemArr = res.data;
      //   this.$forceUpdate();
      // });
    },

    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          let formData = this.form;
          for (let k = 0; k < this.fundDetails.length; k++) {
            let tempDetail = this.fundDetails[k];
            if (tempDetail.itemid == null) {
              this.$modal.msgWarning("请选择服务项目");
              return;
            }
            //判断单位 unitSel
            // try {
            //   //获取服务项目明细
            //   let unitIndex = this.bankaccountlist.findIndex(
            //     (item) => tempDetail.unitno == item.reportNo
            //   );
            //   if (unitIndex > -1) {
            //     tempDetail.unitname = this.bankaccountlist[unitIndex].reportName;
            //   } else {
            //     tempDetail.unitname = tempDetail.unitno;
            //   }
            // } catch {
            //   tempDetail.unitname = tempDetail.unitno;
            // }
          }
          try {
            this.form.unitname = this.$refs.orgSelecter.getOptionByValue(
              this.form.unitno
            ).organizationname;
          } catch {
            this.form.treatmenthospitalname = this.form.treatmenthospitalno;
          }
          this.loading = true;
          //附件处理
          let list = this.fileList;
          if (list.length > 0) {
            this.form.annexbankcard = list.map(item => item.url).join(",");
          }

          this.form.donorname = this.curCase.name;
          this.form.pretaxcost = parseFloat(this.form.amountrequested).toFixed(
            2
          );

          if (this.form.id != null) {
            updateFund(this.form).then(response => {
              this.getfundList();

              this.dialogOpen = false;
              this.getList();
              this.selectDonotor(this.curCase);
              this.$modal.msgSuccess("修改成功");
              this.loading = false;
              for (let m = 0; m < this.fundDetails.length; m++) {
                let tempData = this.fundDetails[m];
                let tempItemArr = tempData.itemArr;
                tempData.fundid = formData.id;
                //获取服务项目明细
                let itemIndex = tempItemArr.findIndex(
                  item => tempData.itemid == item.id
                );
                if (itemIndex > -1) {
                  tempData.itemname = tempItemArr[itemIndex].itemName;
                  tempData.itemid = tempItemArr[itemIndex].id;
                }
                if (tempData.id > 0) {
                  updateFunddetail(tempData).then(response2 => { });
                } else {
                  addFunddetail(tempData).then(response2 => { });
                }
              }
            });
          } else {
            //保存费用申请
            for (let m = 0; m < this.fundDetails.length; m++) {
              let tempData = this.fundDetails[m];
              let tempUtemArr = tempData.itemArr;

              //获取服务项目明细
              let itemIndex = tempUtemArr.findIndex(
                item => tempData.itemid == item.id
              );
              if (itemIndex > -1) {
                tempData.itemname = tempUtemArr[itemIndex].itemName;
                tempData.itemid = tempUtemArr[itemIndex].id;
              }
              //获取applytypename
              let applytypeIndex = this.fundtypeArr.findIndex(
                item => tempData.applytype == item.value
              );
              if (applytypeIndex > -1) {
                tempData.applytypename = this.fundtypeArr[applytypeIndex].label;
              }
              this.fundDetails[m] = tempData;
            }

            this.form.serviceFunddetails = this.fundDetails;
            addorupdateFund(this.form).then(response => {
              if (response.code === 200) {
                this.$modal.msgSuccess("新增成功");
                this.loading = false;
              } else {
                this.$modal.msgError("新增失败：" + response.msg);
                this.loading = false;
              }
            });

            //关闭窗口
            this.loading = false;
            this.dialogOpen = false;
            // this.getfundList();
            this.getList();
            this.selectDonotor(this.curCase);
          }
        }
      });
    },

    getBankAccount() {
      //获取银行账号列表，类型是机构
      listReportname("org").then(res => {
        this.bankaccountlist = res.data;
      });
    },

    getlistUser() {
      listUser().then(res => {
        this.userlist = res.data;
      });
    },

    deleteRows(row, index, rows) {
      this.$confirm("是否确认删除?", "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "success"
      })
        .then(() => {
          if (row.id !== null) {
            delFunddetail(row.id).then(res => {
              if (res.code === 200) {
                this.$confirm("删除成功", "提示", {
                  confirmButtonText: "确定",
                  cancelButtonText: "取消",
                  type: "success"
                }).then(() => {
                  this.$set(rows, rows.splice(index, 1));
                  getownFundDetail(this.form.id).then(res => {
                    this.$set(this.fundDetails, res.data);
                    this.sumTotalFee(row);
                    // this.fundDetails = res.data
                  });
                });
              }
            });
          } else {
            rows.splice(index, 1);
            this.sumTotalFee(row);
          }
        })
        .catch(() => {
          //几点取消的提示
        });
    },

    //计算总金额
    sumTotalFee(row) {
      let allSum = 0;
      if (this.form.applytype != null) {
        for (let i = 0; i < this.fundDetails.length; i++) {
          let totalFee = 0;
          let taxFee = 0;
          if (this.form.applytype == 1 || this.form.applytype == 2) {
            //计算当前报销内容费用合计
            if (!isNaN(parseFloat(this.fundDetails[i].amount))) {
              totalFee += parseFloat(this.fundDetails[i].amount);
              taxFee += parseFloat(this.fundDetails[i].amount);
            }
            if (!isNaN(parseFloat(this.fundDetails[i].taxamount))) {
              totalFee -= parseFloat(this.fundDetails[i].taxamount);
              taxFee -= parseFloat(this.fundDetails[i].taxamount);
            }
          } else if (this.form.applytype == 3) {
            if (
              !isNaN(parseFloat(this.fundDetails[i].price)) &&
              !isNaN(parseFloat(this.fundDetails[i].quantity))
            ) {
              totalFee +=
                parseFloat(this.fundDetails[i].price) *
                parseFloat(this.fundDetails[i].quantity);
            }
          }
          if (!isNaN(parseFloat(taxFee))) {
            this.fundDetails[i].taxedamount = taxFee.toFixed(2);
          }
          allSum += totalFee;
        }
      }
      //this.form.amountrequested = allSum.toFixed(2);
      this.$set(this.form, "amountrequested", allSum.toFixed(2));
      //this.$forceUpdate();
    },

    //获取费用类型
    getCurFundType() {
      getFundTypeAll(this.currentApplyType).then(res => {
        let dataList = res.data;
        this.fundtypeArrAll = dataList;
        this.fundtypeArr = [];
        for (let m = 0; m < dataList.length; m++) {
          this.fundtypeArr.push({
            value: dataList[m].itemType,
            label: dataList[m].itemTypeName
          });
        }
      });
    },

    getItemArr(rowindex, row) {
      let list = this.fundtypeArrAll.filter(r => r.itemType == row.applytype);
      row.itemArr = list[0].itemDetails;
      this.$set(this.fundDetails, rowindex, row);
      //this.loading = true;
      // getItemNames(row.applytype).then((res) => {
      //   this.loading = false;
      //   row.itemArr = res.data;
      //   this.$set(this.fundDetails, rowindex, row);
      // });
    },

    addAlls() {
      this.loading = true;
      this.fundDetails = this.fundDetails.filter(
        r => r.applytype != "" && r.applytype != null
      );
      let listAdd = [];
      //let listAdd = this.fundDetails;
      for (let i = 0; i < this.fundtypeArrAll.length; i++) {
        for (let j = 0; j < this.fundtypeArrAll[i].itemDetails.length; j++) {
          let list = this.fundDetails.filter(
            r =>
              r.applytype == this.fundtypeArrAll[i].itemType &&
              r.itemid == this.fundtypeArrAll[i].itemDetails[j].id
          );
          if (list.length == 0) {
            let rowData = {
              id: null,
              orderno: listAdd.length + 1,
              applytype: this.fundtypeArrAll[i].itemType,
              itemid: this.fundtypeArrAll[i].itemDetails[j].id,
              itemcode: this.fundtypeArrAll[i].itemDetails[j].itemCode,
              recordstatus: "-1",
              itemArr: this.fundtypeArrAll[i].itemDetails,
              beneficiaryname: "点击选择",
              unitname: "点击选择"
            };
            listAdd.push(rowData);
          }
        }
      }
      this.fundDetails = listAdd;
      this.loading = false;
      // let Outerarr = this.fundDetails;
      // Outerarr.map((res) => {
      //   let onelist = this.fundtypeArr;
      //   onelist.map((item) => {
      //     //第一层不相等时；
      //     if (res.applytype !== item.itemType) {
      //       this.addRow();
      //     }
      //   });
      // });
    },

    getUnitList() {
      listOrganization(3).then(res => {
        for (let i = 0; i < res.rows.length; i++) {
          this.unitList.push({
            organizationid: res.rows[i].organizationid,
            organizationname: res.rows[i].organizationname,
            bankname: res.rows[i].bankname,
            bankaccount: res.rows[i].bankaccount
          });
        }
      });
    },

    // 捐献者医学统计打印
    dayin2(id) {
      getdownloadYX(id).then(res => {
        if (res.downloadUrl) {
          var fileUrl = res;
          //获取当前网址
          var urlBase = process.env.VUE_APP_BASE_API;
          var curWWWPath = window.document.location.href;
          var pos = curWWWPath.indexOf(window.document.location.pathname);
          // 创建a标签
          var aEle = document.createElement("a");
          aEle.href =
            curWWWPath.substring(0, pos) + urlBase + fileUrl["downloadUrl"];
          aEle.click();
          this.$alert("下载成功", "提示", {
            confirmButtonText: "确定",
            type: "success"
          });
        }
      });
    },

    //汇总打印
    totaldayin(e) {
      // const id =this.row.id
      getdownloadBX(e).then(res => {
        if (res.downloadUrl) {
          var fileUrl = res;
          //获取当前网址
          var urlBase = process.env.VUE_APP_BASE_API;
          var curWWWPath = window.document.location.href;
          var pos = curWWWPath.indexOf(window.document.location.pathname);
          // 创建a标签
          var aEle = document.createElement("a");
          aEle.href =
            curWWWPath.substring(0, pos) + urlBase + fileUrl["downloadUrl"];
          aEle.click();
          this.$alert("下载成功", "提示", {
            confirmButtonText: "确定",
            type: "success"
          });
        }
      });
    },

    mixExport(id) {
      this.dayin2(id);
      //this.totaldayin(id);
    },

    SearchItem(val, scope) {
      let result = [];
      if (val != "") {
        let tempItemArr = scope.row.itemArr;
        for (let i = 0; i < tempItemArr.length; i++) {
          let pym = tempItemArr[i].itempinyin;
          if (pym != null && pym != undefined && pym != "") {
            if (pym.indexOf(val) != -1) {
              result.push(tempItemArr[i]);
            }
          }
        }
        scope.row.itemArr = result;
      } else {
        getItemNames(scope.row.applytype).then(res => {
          scope.row.itemArr = res.data;
          //this.$set(this.fundDetails, rowindex, row);
        });
      }
    },

    //文件上传
    handleUploadError() { },

    handleremove(file) {
      this.fileList.splice(this.fileList.indexOf(file), 1);
    },

    handleExceed() {
      this.$message.error(`上传文件数量不能超过 ${5} 个!`);
    },

    //文件上传成功回调
    uploadSccess(response, file, fileList) {
      //获取附件信息位置
      if (response.code == 200) {
        this.form.filename = file.raw.name;
        this.$modal.msgSuccess(response.msg);
        this.fileList.push({ name: response.fileName, url: response.fileName });
      } else {
        console.log(response.msg);
      }
    },
    // 下载文件
    downFile(item) {
      const url = process.env.VUE_APP_BASE_API + item.url;
      var a = document.createElement("a");
      var event = new MouseEvent("click");
      a.download = item.name;
      a.href = url;
      a.dispatchEvent(event);
    },

    remove(file) {
      this.fileList.splice(this.fileList.indexOf(file), 1);
    },

    // 点击文件
    Filepopup(index, rows, row) {
      this.atpresent = index;
      this.pdfVisible = true;
      if (this.fundDetails[index].annexfilesList) {
        this.fileListto = this.rbDetails[index].annexfilesList;
      } else {
        this.fileListto = [];
        this.pdfimg = "";
        this.pdftitle = "";
      }
    },
    // 点击已上传文件
    downFile(item) {
      this.pdftitle = item.name;
      let name = item.name.split(".");
      if (name[1] == "pdf") {
        this.$modal.msgWarning("当前文件暂不支持预览");
        this.previewpdf = false;
        this.hintitle = "当前文件暂不支持预览";
      } else if (name[1] == "jpg" || "png") {
        this.previewpdf = true;
        if (item.url) {
          this.pdfimg = item.url;
        } else {
          this.pdfimg = item.response.url;
        }
      } else {
        this.hintitle = "当前文件暂不支持预览";
        this.$modal.msgWarning("当前文件暂不支持预览");
        this.previewpdf = false;
      }
    }
  }
};
</script>
<style scoped>
/* @import url(); 引入公共css类 */
</style>
